# igzg
파이썬 이것저것 모듈

##### LOG

> 2024-08-11 14:51:23  
> utils 함수 주석 작성, `snake case` 사용
>    - get_config  
>    - get_now_str  
>    - write_error  
>    - fwrite  
> 
> \_\_version\_\_ : 0.0.7  
> mySQL: 0.0.5  
> utils: 0.0.2  
